==> odoo_18.5a1.20250907.zip: odoo-18.5a1.post20250907/odoo/addons/theme_treehouse/__manifest__.py <==
{
    'name': 'Treehouse Theme',
    'description': 'Treehouse Theme - Responsive Bootstrap Theme for Odoo CMS',
    'category': 'Theme/Environment',
    'summary': 'Environment, Nature, Ecology, Sustainable Development, Non Profit, NGO, Travels',
    'sequence': 140,
    'version': '2.0.0',
    'depends': ['theme_common'],
    'data': [
        'data/generate_primary_template.xml',
        'data/ir_asset.xml',
        'views/images_library.xml',

        'views/snippets/s_cta_box.xml',
        'views/snippets/s_banner.xml',
        'views/snippets/s_call_to_action.xml',
        'views/snippets/s_carousel.xml',
        'views/snippets/s_cards_grid.xml',
        'views/snippets/s_carousel_intro.xml',
        'views/snippets/s_color_blocks_2.xml',
        'views/snippets/s_comparisons.xml',
        'views/snippets/s_comparisons_horizontal.xml',
        'views/snippets/s_company_team_detail.xml',
        'views/snippets/s_cover.xml',
        'views/snippets/s_card_offset.xml',
        'views/snippets/s_faq_collapse.xml',
        'views/snippets/s_features.xml',
        'views/snippets/s_image_text.xml',
        'views/snippets/s_image_title.xml',
        'views/snippets/s_key_images.xml',
        'views/snippets/s_images_mosaic.xml',
        'views/snippets/s_company_team_grid.xml',
        'views/snippets/s_media_list.xml',
        'views/snippets/s_numbers_list.xml',
        'views/snippets/s_picture.xml',
        'views/snippets/s_freegrid.xml',
        'views/snippets/s_quotes_carousel.xml',
        'views/snippets/s_quotes_carousel_minimal.xml',
        'views/snippets/s_references.xml',
        'views/snippets/s_sidegrid.xml',
        'views/snippets/s_tabs.xml',
        'views/snippets/s_text_block.xml',
        'views/snippets/s_text_image.xml',
        'views/snippets/s_features_wall.xml',
        'views/snippets/s_three_columns.xml',
        'views/snippets/s_title.xml',
        'views/snippets/s_quadrant.xml',
        'views/snippets/s_unveil.xml',
        'views/snippets/s_key_benefits.xml',
        'views/snippets/s_pricelist_boxed.xml',
        'views/snippets/s_striped_center_top.xml',
        'views/snippets/s_intro_pill.xml',
        'views/snippets/s_big_number.xml',
        'views/snippets/s_image_frame.xml',
        'views/snippets/s_wavy_grid.xml',
        'views/snippets/s_text_cover.xml',
        'views/snippets/s_empowerment.xml',
        'views/snippets/s_numbers_boxed.xml',
        'views/snippets/s_split_intro.xml',
        'views/snippets/s_numbers_framed.xml',
        'views/new_page_template.xml',
    ],
    'images': [
        'static/description/treehouse_cover.webp',
        'static/description/treehouse_screenshot.webp',
    ],
    'images_preview_theme': {
        'website.s_sidegrid_default_image_1': '/theme_treehouse/static/src/img/content/s_sidegrid_default_image_1.webp',
        'website.s_sidegrid_default_image_2': '/theme_treehouse/static/src/img/content/s_sidegrid_default_image_2.webp',
        'website.s_sidegrid_default_image_3': '/theme_treehouse/static/src/img/content/s_sidegrid_default_image_3.webp',
        'website.s_sidegrid_default_image_4': '/theme_treehouse/static/src/img/content/s_sidegrid_default_image_4.webp',
        'website.s_text_image_default_image': '/theme_treehouse/static/src/img/content/text_image.webp',
        'website.library_image_03': '/theme_treehouse/static/src/img/backgrounds/05.webp',
        'website.library_image_13': '/theme_treehouse/static/src/img/content/s_freegrid_default_image_2.webp',
        'website.library_image_10': '/theme_treehouse/static/src/img/content/s_freegrid_default_image_3.webp',
        'website.library_image_05': '/theme_treehouse/static/src/img/content/s_freegrid_default_image_4.webp',
        'website.library_image_14': '/theme_treehouse/static/src/img/content/s_freegrid_default_image_5.webp',
        'website.library_image_16': '/theme_treehouse/static/src/img/content/s_freegrid_default_image_6.webp',
    },
    'configurator_snippets': {
        'homepage': ['s_sidegrid', 's_numbers_list', 's_color_blocks_2', 's_references', 's_freegrid'],
    },
    'new_page_templates': {
        'about': {
            'personal': ['s_text_cover', 's_image_text', 's_text_block_h2', 's_numbers', 's_features', 's_call_to_action'],
        },
    },
    'author': 'Odoo S.A.',
    'license': 'LGPL-3',
    'live_test_url': 'https://theme-treehouse.odoo.com',
    'assets': {
        'website.assets_editor': [
            'theme_treehouse/static/src/js/tour.js',
        ],
    }
}

==> odoo_19.0.20251009.zip: odoo-19.0.post20251009/odoo/addons/theme_treehouse/__manifest__.py <==
{
    'name': 'Treehouse Theme',
    'description': 'Treehouse Theme - Responsive Bootstrap Theme for Odoo CMS',
    'category': 'Theme/Environment',
    'summary': 'Environment, Nature, Ecology, Sustainable Development, Non Profit, NGO, Travels',
    'sequence': 140,
    'version': '2.0.0',
    'depends': ['theme_common'],
    'data': [
        'data/generate_primary_template.xml',
        'data/ir_asset.xml',
        'views/images_library.xml',

        'views/snippets/s_cta_box.xml',
        'views/snippets/s_banner.xml',
        'views/snippets/s_call_to_action.xml',
        'views/snippets/s_carousel.xml',
        'views/snippets/s_cards_grid.xml',
        'views/snippets/s_carousel_intro.xml',
        'views/snippets/s_color_blocks_2.xml',
        'views/snippets/s_comparisons.xml',
        'views/snippets/s_comparisons_horizontal.xml',
        'views/snippets/s_company_team_detail.xml',
        'views/snippets/s_cover.xml',
        'views/snippets/s_card_offset.xml',
        'views/snippets/s_faq_collapse.xml',
        'views/snippets/s_features.xml',
        'views/snippets/s_image_text.xml',
        'views/snippets/s_image_title.xml',
        'views/snippets/s_key_images.xml',
        'views/snippets/s_images_mosaic.xml',
        'views/snippets/s_company_team_grid.xml',
        'views/snippets/s_media_list.xml',
        'views/snippets/s_numbers_list.xml',
        'views/snippets/s_picture.xml',
        'views/snippets/s_freegrid.xml',
        'views/snippets/s_quotes_carousel.xml',
        'views/snippets/s_quotes_carousel_minimal.xml',
        'views/snippets/s_references.xml',
        'views/snippets/s_sidegrid.xml',
        'views/snippets/s_tabs.xml',
        'views/snippets/s_text_block.xml',
        'views/snippets/s_text_image.xml',
        'views/snippets/s_features_wall.xml',
        'views/snippets/s_three_columns.xml',
        'views/snippets/s_title.xml',
        'views/snippets/s_quadrant.xml',
        'views/snippets/s_unveil.xml',
        'views/snippets/s_key_benefits.xml',
        'views/snippets/s_pricelist_boxed.xml',
        'views/snippets/s_striped_center_top.xml',
        'views/snippets/s_intro_pill.xml',
        'views/snippets/s_big_number.xml',
        'views/snippets/s_image_frame.xml',
        'views/snippets/s_wavy_grid.xml',
        'views/snippets/s_text_cover.xml',
        'views/snippets/s_empowerment.xml',
        'views/snippets/s_split_intro.xml',
        'views/snippets/s_numbers_framed.xml',
        'views/new_page_template.xml',
    ],
    'images': [
        'static/description/treehouse_cover.webp',
        'static/description/treehouse_screenshot.webp',
    ],
    'images_preview_theme': {
        'website.s_sidegrid_default_image_1': '/theme_treehouse/static/src/img/content/s_sidegrid_default_image_1.webp',
        'website.s_sidegrid_default_image_2': '/theme_treehouse/static/src/img/content/s_sidegrid_default_image_2.webp',
        'website.s_sidegrid_default_image_3': '/theme_treehouse/static/src/img/content/s_sidegrid_default_image_3.webp',
        'website.s_sidegrid_default_image_4': '/theme_treehouse/static/src/img/content/s_sidegrid_default_image_4.webp',
        'website.s_text_image_default_image': '/theme_treehouse/static/src/img/content/text_image.webp',
        'website.library_image_03': '/theme_treehouse/static/src/img/backgrounds/05.webp',
        'website.library_image_13': '/theme_treehouse/static/src/img/content/s_freegrid_default_image_2.webp',
        'website.library_image_10': '/theme_treehouse/static/src/img/content/s_freegrid_default_image_3.webp',
        'website.library_image_05': '/theme_treehouse/static/src/img/content/s_freegrid_default_image_4.webp',
        'website.library_image_14': '/theme_treehouse/static/src/img/content/s_freegrid_default_image_5.webp',
        'website.library_image_16': '/theme_treehouse/static/src/img/content/s_freegrid_default_image_6.webp',
    },
    'configurator_snippets': {
        'homepage': ['s_sidegrid', 's_numbers_list', 's_color_blocks_2', 's_references', 's_freegrid'],
    },
    'configurator_snippets_addons': {
        'website_sale': {
            'homepage': [
                ('website_sale.s_dynamic_snippet_category_list', 'after', 's_color_blocks_2'),
            ],
        },
    },
    'theme_customizations': {
        'website_sale.s_dynamic_snippet_category_list': {
            'data_attributes': {
                'gap': '3',
                'size': 'small',
                'alignment': 'left',
            },
            'background': {
                'color': 'o_cc2',
                'shape': {
                    'data-oe-shape-data': '{"shape":"web_editor/Connections/09", "colors":{"c5":"o-color-4"}, "flip":["x"]}',
                    'element': """<div class="o_we_shape o_web_editor_Connections_09" style="background-image: url('/web_editor/shape/web_editor/Connections/09.svg?c5=o-color-4&amp;flip=x');""",
                },
            },
            'add_classes': [
                'pt88', 'pb144',
            ],
            'remove_classes': [
                'pt64', 'pb64',
            ],
        },
    },
    'new_page_templates': {
        'about': {
            'personal': ['s_text_cover', 's_image_text', 's_text_block_h2', 's_numbers', 's_features', 's_call_to_action'],
        },
    },
    'author': 'Odoo S.A.',
    'license': 'LGPL-3',
    'live_test_url': 'https://theme-treehouse.odoo.com',
    'assets': {
        'website.assets_editor': [
            'theme_treehouse/static/src/js/tour.js',
        ],
    }
}
